@@ -141,7 +141,6 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
-          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -151,9 +150,9 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
-          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
+          'SESSION_COOKIE_HTTPONLY = True',
           "  'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
@@ -297,7 +296,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack'],
+          :tag    => ['openstack', 'horizon-package'],
           :name   => platforms_params[:memcache_package],
          )
       }
@@ -345,23 +344,21 @@ describe 'horizon' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl        => true,
-          :servername        => 'some.host.tld',
-          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key       => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
-          :ssl_verify_client => 'optional',
+          :listen_ssl   => true,
+          :servername   => 'some.host.tld',
+          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key  => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
         })
       end
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :bind_address      => nil,
-          :listen_ssl        => true,
-          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key       => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
-          :ssl_verify_client => 'optional',
+          :bind_address => nil,
+          :listen_ssl   => true,
+          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key  => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
         })
       end
     end
